
# Pylogex -A Simple Python Log Extractor

A simple command-line utility that lets us filter textual input stream based on regular 
expression pattern and generate log in CSV or JSON format as output stream

## Authors

- [@Sanskriti](https://www.git.corp.adobe.com/sanskriti)
- [@Ritika Kayal](https://www.git.corp.adobe.com/rkayal)
- [@Surabhi Singh](https://www.git.corp.adobe.com/surabhis)
- [@Saumya Shrivastava](https://www.git.corp.adobe.com/sshrivastava)


## How to run ?
```
python <filename> 'A Reguar Expression in quotes'
```

## Optional Argument Parameters 

```
optional arguments:
 -h, --help show this help message and exit
 -i INFILE, --input=INFILE
 read input (logs) from <INFILE>
 -o OUTFILE, --output=OUTFILE
 save the extracted data to <OUTFILE>
 -j, --json generate output in JSON format
 -c, --csv generate output in CSV format (default)
```
## Install my project with pip
```
pip install package-template
```
## Requirements
Python